@@ -1,7 +1,8 @@
 labbcat.url <- "https://labbcat.canterbury.ac.nz/demo"
-labbcatCredentials(labbcat.url, "demo", "demo")
 
 test_that("getCorpusIds works", {
+    if (!is.null(labbcatCredentials(labbcat.url, "demo", "demo"))) skip("Server not available")
+
     corpora <- getCorpusIds(labbcat.url)
     expect_true(length(corpora) >= 2)
     expect_true("QB" %in% corpora)
