@@ -1,7 +1,8 @@
 labbcat.url <- "https://labbcat.canterbury.ac.nz/demo"
-labbcatCredentials(labbcat.url, "demo", "demo")
 
 test_that("getGraphIdsInCorpus works", {
+    if (!is.null(labbcatCredentials(labbcat.url, "demo", "demo"))) skip("Server not available")
+
     ids <- getGraphIdsInCorpus(labbcat.url, "QB")
     expect_equal(length(ids), 22)
     expect_true("QB247_Jacqui.eaf" %in% ids)
