@@ -1,7 +1,8 @@
 labbcat.url <- "https://labbcat.canterbury.ac.nz/demo"
-labbcatCredentials(labbcat.url, "demo", "demo")
 
 test_that("getLayerIds works", {
+    if (!is.null(labbcatCredentials(labbcat.url, "demo", "demo"))) skip("Server not available")
+
     layerIds <- getLayerIds(labbcat.url)
     expect_true(length(layerIds) >= 41)
     expect_true("transcript" %in% layerIds)
